@@ -101,7 +101,7 @@ class ClDesktopAction(Action):
                    'ur_home_path,False)'
          },
         {'name': 'need_skel:sync_skel',
-         'message': _("Coping skel data"),
+         'message': _("Copying skel data"),
          'method': 'Desktop.syncSkel(ur_home_path,ur_uid,ur_gid)'
          },
         # настроить пользовательских профиль шаблонами
